Crate vtcode_macros

Crate vtcode_macros 

Derive Macros

DebugNoInline
Derive macro equivalent to #[derive(Debug)] but with #[inline(never)] on the generated fmt implementation.
StringNewtype
Derive macro that generates the same boilerplate as the string_newtype! declarative macro. Apply to a tuple struct wrapping a single String field.